var languageNames = {
"en-US": "Engelsk (USA)",
"sq": "Albansk",
"am": "Amharisk",
"ar": "Arabisk",
"ast": "Asturisk",
"bn": "Bengali",
"bn-IN": "Bengali (Indien)",
"bs": "Bosnisk",
"bg": "Bulgarsk",
"ca": "Catalansk",
"ca-valencia": "Catalan (Valencia)",
"zh-CN": "Kinesisk (simplificeret)",
"zh-TW": "Kinesisk (traditionelt)",
"hr": "Kroatisk",
"cs": "Tjekkisk",
"da": "Dansk",
"nl": "Hollandsk",
"dz": "Dzongkha",
"en-GB": "Engelsk (UK)",
"en-ZA": "Engelsk (SA)",
"eo": "Esperanto",
"et": "Estisk",
"eu": "Baskisk",
"fi": "Finsk",
"fr": "Fransk",
"gl": "Galicisk",
"ka": "Georgisk",
"de": "Tysk",
"el": "Græsk",
"gu": "Gujarati",
"he": "Hebræisk",
"hi": "Hindi",
"hu": "Ungarsk",
"id": "Indonesisk",
"is": "Islandsk",
"it": "Italiensk",
"ja": "Japansk",
"km": "Khmer",
"ko": "Koreansk",
"lo": "Laotisk",
"lv": "Lettisk",
"lt": "Litauisk",
"mk": "Makedonsk",
"ne": "Nepalesisk",
"nn": "Norsk nynorsk",
"nb": "Norsk bokmål",
"om": "Oromo",
"pl": "Polsk",
"pt": "Portugisisk",
"pt-BR": "Portuguese (Brazil)",
"ro": "Rumænsk",
"ru": "Russisk",
"sid": "Sidama",
"si": "Singalesisk",
"sk": "Slovakisk",
"sl": "Slovensk",
"dsb": "Sorbian (Lower)",
"hsb": "Sorbian (Upper)",
"es": "Spansk",
"sv": "Svensk",
"tg": "tadsjikisk",
"ta": "Tamilsk",
"bo": "Tibetansk",
"tr": "Tyrkisk",
"ug": "Uyghur",
"uk": "Ukrainsk",
"vi": "Vietnamesisk",
};
